# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import enum

import winrt.system
from winrt._winrt_windows_graphics_printing_printsupport import (
    PrintSupportCommunicationErrorDetectedEventArgs,
    PrintSupportExtensionSession,
    PrintSupportExtensionTriggerDetails,
    PrintSupportIppCommunicationConfiguration,
    PrintSupportIppCommunicationTimeouts,
    PrintSupportMxdcImageQualityConfiguration,
    PrintSupportPrintDeviceCapabilitiesChangedEventArgs,
    PrintSupportPrintDeviceCapabilitiesUpdatePolicy,
    PrintSupportPrintTicketElement,
    PrintSupportPrintTicketValidationRequestedEventArgs,
    PrintSupportPrinterSelectedEventArgs,
    PrintSupportSessionInfo,
    PrintSupportSettingsActivatedEventArgs,
    PrintSupportSettingsUISession,
)

__all__ = [
    "IppCommunicationErrorKind",
    "IppPrinterCommunicationKind",
    "SettingsLaunchKind",
    "WorkflowPrintTicketValidationStatus",
    "XpsImageQuality",
    "PrintSupportCommunicationErrorDetectedEventArgs",
    "PrintSupportExtensionSession",
    "PrintSupportExtensionTriggerDetails",
    "PrintSupportIppCommunicationConfiguration",
    "PrintSupportIppCommunicationTimeouts",
    "PrintSupportMxdcImageQualityConfiguration",
    "PrintSupportPrintDeviceCapabilitiesChangedEventArgs",
    "PrintSupportPrintDeviceCapabilitiesUpdatePolicy",
    "PrintSupportPrintTicketElement",
    "PrintSupportPrintTicketValidationRequestedEventArgs",
    "PrintSupportPrinterSelectedEventArgs",
    "PrintSupportSessionInfo",
    "PrintSupportSettingsActivatedEventArgs",
    "PrintSupportSettingsUISession",
]

class IppCommunicationErrorKind(enum.IntEnum):
    OTHER = 0
    TIMEOUT = 1
    CONNECTION_ERROR = 2
    ACCESS_DENIED = 3

class IppPrinterCommunicationKind(enum.IntEnum):
    NETWORK = 0
    USB = 1
    PRINTER_CONNECTION = 2
    UNIVERSAL_PRINT = 3
    VIRTUAL_PRINTER = 4

class SettingsLaunchKind(enum.IntEnum):
    JOB_PRINT_TICKET = 0
    USER_DEFAULT_PRINT_TICKET = 1

class WorkflowPrintTicketValidationStatus(enum.IntEnum):
    RESOLVED = 0
    CONFLICTING = 1
    INVALID = 2

class XpsImageQuality(enum.IntEnum):
    JPEG_HIGH_COMPRESSION = 0
    JPEG_MEDIUM_COMPRESSION = 1
    JPEG_LOW_COMPRESSION = 2
    PNG = 3

